@@ -102,6 +102,8 @@ class Controllers():
                offset,
                filters,
                lookup,
+               term_context,
+               *,
                score_threshold=0,
                sort_fields=None):
         search_indexes = self._validate_types(types)
@@ -113,6 +115,9 @@ class Controllers():
                 multi_match_type=self.multi_match_type,
                 multi_match_operator=self.multi_match_operator)
 
+        if term_context:
+            query = query.apply_term_context(term_context, self.text_fields)
+
         # Apply the filters
         query = query.apply_filters(filters)
 
@@ -134,7 +139,7 @@ class Controllers():
         # Apply highlighting
         if term and self.dont_highlight != '*' and '*' not in self.dont_highlight:
             highlighted = True
-            query = query.apply_highlighting()
+            query = query.apply_highlighting(term, self.text_fields)
         else:
             highlighted = False
 
@@ -160,28 +165,22 @@ class Controllers():
         hits = [j[1] for j in sorted(hits, key=lambda i: i[0])]
 
         default_sort_score = (0,)
-        if highlighted:
-            search_results = [
-                dict(
-                    source=self._merge_highlight_into_source(
-                        hit['_source'],
-                        hit['highlight'],
-                        self.dont_highlight
-                    ),
-                    type=hit['_type'],
-                    score=hit['_score'] or hit.get('sort', default_sort_score)[0]
-                )
-                for hit in hits
-            ]
-        else:
-            search_results = [
-                dict(
-                    source=hit['_source'],
-                    type=hit['_type'],
-                    score=hit['_score'] or hit.get('sort', default_sort_score)[0]
-                )
-                for hit in hits
-            ]
+        search_results = [
+            dict(
+                source=self._merge_highlight_into_source(
+                    hit['_source'],
+                    hit['highlight'],
+                    self.dont_highlight
+                ),
+                type=hit['_type'],
+                score=hit['_score'] or hit.get('sort', default_sort_score)[0]
+            ) if 'highlight' in hit else dict(
+                source=hit['_source'],
+                type=hit['_type'],
+                score=hit['_score'] or hit.get('sort', default_sort_score)[0]
+            )
+            for hit in hits
+        ]
 
         return dict(
             search_counts=dict(
@@ -192,7 +191,7 @@ class Controllers():
             search_results=search_results
         )
 
-    def count(self, es_client, term, from_date, to_date, config):
+    def count(self, es_client, term, from_date, to_date, config, term_context):
         counts = {}
         for item in config:
             doc_types = item['doc_types']
@@ -206,6 +205,8 @@ class Controllers():
                     multi_match_type=self.multi_match_type,
                     multi_match_operator=self.multi_match_operator
                 )
+            if term_context:
+                query_results = query_results.apply_term_context(term_context, self.text_fields)
             query_results = query_results\
                 .apply_filters(filters)\
                 .apply_pagination(0, 0)\
