@@ -48,8 +48,7 @@ class Query():
     def filter(self, t):
         return self.query_bool(t)\
                         .setdefault('filter', {})\
-                        .setdefault('bool', {})\
-                        .setdefault('should', [])
+                        .setdefault('bool', {})
 
     def must_not(self, t):
         return self.query_bool(t)\
@@ -106,6 +105,27 @@ class Query():
 
         return self
 
+    def apply_term_context(self, terms, text_fields):
+        multi_match_type = 'most_fields'
+        multi_match_operator = 'or'
+        for type_name in self.types:
+            search_fields = text_fields[type_name]
+            search_fields = [
+                x[1] for x in search_fields if x[0] == 'inexact'
+            ]
+            matcher = dict(
+                multi_match=dict(
+                    query=terms,
+                    fields=search_fields,
+                    type=multi_match_type,
+                    operator=multi_match_operator,
+                    tie_breaker=0.3
+                )
+            )
+            self.filter(type_name).setdefault('must', []).append(matcher)
+
+        return self
+
     def apply_scoring(self):
         for type_name in self.types:
             fs = self.q[type_name].setdefault('query', {}).setdefault('function_score', {})
@@ -147,10 +167,16 @@ class Query():
             })
         return self
 
-    def apply_highlighting(self):
+    def apply_highlighting(self, term, search_fields):
         for type_name in self.types:
             self.q[type_name]['highlight'] = dict(
-                fields={'*': {}}
+                fields={'*': {}},
+                highlight_query=dict(
+                    multi_match=dict(
+                        query=term,
+                        fields=[f for k, f in search_fields[type_name] if k in ('inexact', 'natural')],
+                    )
+                )
             )
         return self
 
@@ -240,7 +266,7 @@ class Query():
             return self
 
         for type_name, clause in should_clauses.items():
-            self.filter(type_name).append(clause)
+            self.filter(type_name).setdefault('should', []).append(clause)
         self.filtered_type_names = set(should_clauses.keys())
         return self
 
